#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include "scode.h"
#include "config.h"
#include "gpio.h"
#include "log.h"
#include "fbinit.h"
#include "time_func.h"
#include "sysinput.h"

static void do_draw(void)
{
  /*
  tmp = (char *)Fb_Ptr;
  memset(tmp, 0xFF, Fb_Info->screenbytes / 2);
  memset(tmp + (Fb_Info->screenbytes / 2), 0x1B, Fb_Info->screenbytes / 2);
  */
  UINT16 pixel = Fb_Info->green_mask;
  unsigned npix = Fb_Info->screenbytes / sizeof(UINT16);
  UINT16 *p = Fb_Ptr;
  unsigned i;

  for (i=0; i<npix; i++)
    *p++ = pixel;
}

int main(int argc, char *argv[])
{
  HRESULT hr;
  int running = 1;
  MSG msg;
  char *tmp;

  Time_init();
  hr = Config_setup(argc, argv);
  if (FAILED(hr))
    return EXIT_FAILURE;
  else if (hr != S_OK)
    return EXIT_SUCCESS;
  if (FAILED(Fb_setup()))
    return EXIT_FAILURE;
  if (FAILED(Gpio_setup()))
    return EXIT_FAILURE;
  if (FAILED(Sys_enable_input()))
    return EXIT_FAILURE;
  Log(LINFO, "Pausing at startup.");
  sleep(5); /* wait to show off splash screen */

  Fb_clear();
  /* temporary drawing here */
  do_draw();
 
  Log(LINFO, "System ready.");

  while (running)
  {
    if (Mq_peek(Sys_Queue, &msg, PEEK_REMOVE))
    {
      switch (msg.message)
      {
	case WM_HWBUTTONDOWN:
	  Log(LINFO, "Button %d was pressed.", (int)(msg.attrs[0]));
	  break;

	case WM_HWBUTTONUP:
	  Log(LINFO, "Button %d was released.", (int)(msg.attrs[0]));
	  if (msg.attrs[0] == 1)
	  {
	    Log(LINFO, "Backlight ON.");
	    Gpio_set_backlight(GSB_BACKLIGHT_MAX);
	  }
	  if (msg.attrs[0] == 2)
	  {
	    Log(LINFO, "Backlight OFF.");
	    Gpio_set_backlight(0);
	  }
	  if (msg.attrs[0] == 4)
	  {
	    Log(LINFO, "Quitting the message loop.");
	    running = 0;
	  }
	  break;

	default:
	  break;
      }
    }
  }
  
  return EXIT_SUCCESS;
}
